@@ -1,8 +1,7 @@
 # -*- mode: Perl -*-
 package MRTG_lib;
-
 ###################################################################
-# MRTG 2.14.4  Support library MRTG_lib.pm
+# MRTG 2.14.6  Support library MRTG_lib.pm
 ###################################################################
 # Created by Tobias Oetiker <tobi@oetiker.ch>
 #            and Dave Rand <dlr@bungi.com>
@@ -18,12 +17,14 @@ package MRTG_lib;
 require 5.005;
 use strict;
 use vars qw($OS $SL $PS @EXPORT @ISA $VERSION %timestrpospattern);
-if (eval { require Net_SNMP_util} ) {
+
+if (eval {local $SIG{__DIE__}; require Net_SNMP_util} ) {
 	import Net_SNMP_util;
+} else {
+	require SNMP_util; 
+        import SNMP_util;
 }
-else {
-	require SNMP_util; import SNMP_util;
-}
+
 my %mrtgrules;
 
 BEGIN {
@@ -147,7 +148,7 @@ $VERSION = 2.100016;
        [sub{length($_[0]) == 1}, sub{"$_[0] must be one character long"}],
 
        'snmpoptions' =>
-       [sub{ eval( '{'.$_[0].'}' ); return not $@},
+       [sub{ debug('eval',"snmpotions $_[0]");local $SIG{__DIE__}; eval( '{'.$_[0].'}' ); return not $@},
         sub{"Must have the format \"OptA => Number, OptB => 'String', ... \""}],
 
        'conversioncode' =>
@@ -158,7 +159,7 @@ $VERSION = 2.100016;
        [sub{1}, sub{"Internal Error"}], #will test this later
 
        'snmpoptions[]' =>
-       [sub{ eval( '{'.$_[0].'}' ); return not $@},
+       [sub{ debug('eval',"snmpotions[] $_[0]");local  $SIG{__DIE__}; eval('{'.$_[0].'}' ); return not $@},
         sub{"Must have the format \"OptA => Number, OptB => 'String', ... \""}],
 
        'routeruptime[]' => 
@@ -619,7 +620,7 @@ sub cfgcheck ($$$$;$) {
     my(@known_options) = qw(growright bits noinfo absolute gauge nopercent avgpeak derive
 			    integer perhour perminute transparent dorelpercent 
 			    unknaszero withzeroes noborder noarrow noi noo
-			    nobanner nolegend logscale secondmean pngdate printrouter);
+			    nobanner nolegend logscale secondmean pngdate printrouter expscale);
 
     snmpmapOID('hrSystemUptime' => '1.3.6.1.2.1.25.1.1');
 
@@ -685,7 +686,9 @@ sub cfgcheck ($$$$;$) {
     }
     if(defined $$cfg{libadd}){
         ensureSL(\$$cfg{libadd});
-        eval "use lib qw($$cfg{libadd})";
+        debug('eval',"libadd $$cfg{libadd}\n");
+	local $SIG{__DIE__};
+        eval "use lib qw( $$cfg{libadd} )";
 	my @match;
 	foreach my $dir (@INC){
 		push @match, $dir if -f "$dir/RRDs.pm";
@@ -726,6 +729,8 @@ sub cfgcheck ($$$$;$) {
                 unless defined $found;
     }
     if (defined $$cfg{snmpoptions}) {
+	   debug('eval',"redef snmpotions $cfg->{snmpoptions}");
+	   local $SIG{__DIE__};
            $cfg->{snmpoptions} = eval('{'.$cfg->{snmpoptions}.'}');
     }
 
@@ -744,8 +749,9 @@ sub cfgcheck ($$$$;$) {
     if( exists $cfg->{ conversioncode } ) {
         open CONV, $cfg->{ conversioncode }
             or die "ERROR: Can't open file $cfg->{ conversioncode }\n";
-        my $code = "package MRTGConversion;\n". join( '', <CONV> ) . "1;\n";
+        my $code = "local \$SIG{__DIE__};package MRTGConversion;\n". join( '', <CONV> ) . "1;\n";
         close CONV;
+        debug('eval',"covnversioncode  $cfg->{ conversioncode }");
         die "ERROR: File $cfg->{ conversioncode } conversion code evaluation failed\n$@\n"
             unless eval $code;
     }
@@ -757,6 +763,8 @@ sub cfgcheck ($$$$;$) {
 		$rcfg->{snmpoptions}{$rou} = {%{$cfg->{snmpoptions}}}
 		  if defined $cfg->{snmpoptions};
     	} else {
+                debug('eval',"redef snmpoptions[$rou] $rcfg->{snmpoptions}{$rou}");
+ 		local $SIG{__DIE__};
     	        $rcfg->{snmpoptions}{$rou} = eval('{'.$rcfg->{snmpoptions}{$rou}.'}');
         }
         $rcfg->{snmpoptions}{$rou}{avoid_negative_request_ids} = 1;
@@ -1274,7 +1282,7 @@ sub targparser( $$$$$ ) {
 	# will match. Therefore the match must be postprocessed to check that
 	# $ifOID and $ifAlt are not both null.
 	my $ifComplex =
-		'([a-zA-Z0-9]*(?:\.\d+)*?)' .	# OID possibly starting with a MIB name ($if->{OID})
+		'([-a-zA-Z0-9]*(?:\.\d+)*?)' .	# OID possibly starting with a MIB name ($if->{OID})
 		'(' .							# Interface specification alternatives: ($if->{Alt})
 			'\.' .						#  separator
 			$ifSimple .					#  simple alternatives (6 variables)
