@@ -1,5 +1,5 @@
 /*
- MRTG 2.14.4  -- Rateup
+ MRTG 2.14.6  -- Rateup
  *********************
 
  Rateup is a fast add-on to the great MRTG Traffic monitor.  It makes
@@ -83,7 +83,7 @@
 #include <gd.h>
 #include <gdfonts.h>
 
-char *VERSION = "2.14.4";
+char *VERSION = "2.14.6";
 char *program, *router, *routerpath;
 int histvalid;
 
@@ -101,6 +101,7 @@ short options = 0;
 #define OPTION_PRINTROUTER	0x0200	/* show title in graph */
 #define OPTION_LOGGRAPH		0x0400	/* Use a logarithmic Y axis */
 #define OPTION_MEANOVER		0x0800	/* max Y = mean-above-the-mean */
+#define OPTION_EXPGRAPH		0x1000	/* exponential scale (opposite of logscale) */
 
 time_t NOW;
 
@@ -110,6 +111,7 @@ time_t timestamp;
 char bufftime[32];
 
 char *short_si_def[] = { "", "k", "M", "G", "T" };
+int kMGnumber = 4;
 char **short_si = short_si_def;
 char *longup = NULL;
 char *shortup = NULL;
@@ -153,7 +155,7 @@ int col_outp[3];
 
 long long kilo = (long long) 1000;
 char *kMG = (char *) NULL;
-int kMGnumber = 0;
+
 
 #define MAXL	200		/* Maximum length of last in & out fields */
 
@@ -479,28 +481,16 @@ image (file, maxvi, maxvo, maxx, maxy, xscale, yscale, growright, step, bits,
         {
           short_si_out = kMG;
           kMGnumber = 0;
+	  short_si[0] = kMG;
           while ((short_si_out = strchr (short_si_out, ',')) != NULL)
 	    {
+	      short_si_out[0] = '\0';
 	      short_si_out++;
-	      kMGnumber++;
+              short_si[++kMGnumber] = short_si_out;
 	    }
-
-          short_si = calloc(kMGnumber + 1, sizeof(*short_si));
-          short_si_out = kMG;
-          for (kMGnumber = 0; ; kMGnumber++)
-            {
-	      short_si[kMGnumber] = short_si_out;
-	      short_si_out = strchr(short_si_out, ',');
-	      if (short_si_out == NULL) break;
-	      short_si_out++;
-	    }
-	}
-    }
-  else
-    {
-      kMGnumber = 4;
-    }
-
+        }
+     }
+  
   /* mangle the 0.25*maxv value so, that we get a number with either */
   /* one or two digits != 0 and these digits should be at the  */
   /* start of the number ... */
@@ -832,6 +822,18 @@ image (file, maxvi, maxvo, maxx, maxy, xscale, yscale, growright, step, bits,
       origmaxvi = logscale (origmaxvi, maxy);
       origmaxvo = logscale (origmaxvo, maxy);
     }	/* end of primary log and second-mean scaling code (more below) */
+  else if (options & OPTION_EXPGRAPH)
+    {
+      for (x = 0; x < maxx; x++)
+        {
+          lhist[x].in = expscale (lhist[x].in, maxy);
+          lhist[x].out = expscale (lhist[x].out, maxy);
+          lhist[x].inmax = expscale (lhist[x].inmax, maxy);
+          lhist[x].outmax = expscale (lhist[x].outmax, maxy);
+        }
+      origmaxvi = expscale (origmaxvi, maxy);
+      origmaxvo = expscale (origmaxvo, maxy);
+    }
 
   /* the graph is made ten pixels higher to acomodate the x labels */
   graph = gdImageCreate (XSIZE, YSIZE);
@@ -1023,6 +1025,8 @@ image (file, maxvi, maxvo, maxx, maxy, xscale, yscale, growright, step, bits,
 	  temp = sca_max_q * i;
 	  if (options & OPTION_LOGGRAPH)
 	     temp = expscale(maxy * i / ytics, maxy) * ytics * sca_max_q / maxy;
+	  else if (options & OPTION_EXPGRAPH)
+	     temp = logscale(maxy * i / ytics, maxy) * ytics * sca_max_q / maxy;
 	  else
 	     temp = sca_max_q * i;
 	  sprintf (ylab, "%6.1f %s", temp, short_si_out);
@@ -1811,7 +1815,7 @@ main (argc, argv)
     /* jpt, april 2006 : 3 lines for date & time logging */
     (void) time(&timestamp);
     stLocal = localtime(&timestamp);
-    strftime(bufftime, 32, "%d-%m-%Y %H:%M:%S", stLocal);
+    strftime(bufftime, 32, "%Y-%m-%d %H:%M:%S", stLocal);
 
   /* Is Argv[1] a path/file to passed parameters? */
   if ((argc > 1) && (strncasecmp (argv[1], "-F", 2) == 0))
@@ -2016,11 +2020,13 @@ main (argc, argv)
 	    case 'l':		/* logarithmic scaling */
 	      options |= OPTION_LOGGRAPH;
 	      options &= ~OPTION_MEANOVER;
+	      options &= ~OPTION_EXPGRAPH;
 	      used = 1;
 	      break;
 	    case 'm':		/* second-mean scaling */
 	      options |= OPTION_MEANOVER;
 	      options &= ~OPTION_LOGGRAPH;
+	      options &= ~OPTION_EXPGRAPH;
 	      used = 1;
 	      break;
 	    case 'p':		/* print router name in image */
@@ -2035,6 +2041,12 @@ main (argc, argv)
 	      options &= ~OPTION_TRANSPARENT;
 	      used = 1;
 	      break;
+            case 'x':		/* exponential scaling */
+	      options |= OPTION_EXPGRAPH;
+	      options &= ~OPTION_MEANOVER;
+	      options &= ~OPTION_LOGGRAPH;
+	      used = 1;
+	      break;
 	    case 'z':		/* unknown as zero */
 	      options |= OPTION_UNKNASZERO;
 	      used = 1;
